@@ -194,6 +194,7 @@ class Specs(SpecSet):
     getenforce = RegistryPoint()
     getsebool = RegistryPoint()
     gfs2_file_system_block_size = RegistryPoint(multi_output=True)
+    group_info = RegistryPoint(filterable=True)
     glance_api_conf = RegistryPoint()
     glance_api_log = RegistryPoint(filterable=True)
     glance_cache_conf = RegistryPoint()
@@ -327,13 +328,16 @@ class Specs(SpecSet):
     ls_ocp_cni_openshift_sdn = RegistryPoint()
     ls_origin_local_volumes_pods = RegistryPoint()
     ls_osroot = RegistryPoint()
-    ls_run_systemd_generator = RegistryPoint()
+    ls_run_systemd = RegistryPoint()
     ls_R_var_lib_nova_instances = RegistryPoint()
     ls_sys_firmware = RegistryPoint()
     ls_usr_bin = RegistryPoint(filterable=True)
     ls_usr_lib64 = RegistryPoint(filterable=True)
     ls_usr_lib_systemd = RegistryPoint()
+    ls_usr_local_lib_systemd = RegistryPoint()
+    ls_usr_local_share_systemd = RegistryPoint()
     ls_usr_sbin = RegistryPoint(filterable=True)
+    ls_usr_share_systemd = RegistryPoint()
     ls_var_cache_pulp = RegistryPoint()
     ls_var_lib_mongodb = RegistryPoint()
     ls_var_lib_nova_instances = RegistryPoint()
@@ -656,6 +660,7 @@ class Specs(SpecSet):
     subscription_manager_list_installed = RegistryPoint()
     subscription_manager_installed_product_ids = RegistryPoint(filterable=True)
     subscription_manager_release_show = RegistryPoint()
+    sudoers = RegistryPoint(multi_output=True, filterable=True)
     swift_conf = RegistryPoint()
     swift_log = RegistryPoint(filterable=True)
     swift_object_expirer_conf = RegistryPoint()
